# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/cluster.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\014ClusterProto'),
  serialized_pb=_b('\n\x1eprotobuf/cluster/cluster.proto\x12\x16grakn.protocol.cluster\"<\n\x07\x43luster\x1a\x31\n\x07Servers\x1a\x05\n\x03Req\x1a\x1f\n\x03Res\x12\x18\n\x07servers\x18\x01 \x03(\tR\x07serversB&\n\x16grakn.protocol.clusterB\x0c\x43lusterProtob\x06proto3')
)




_CLUSTER_SERVERS_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.cluster.Cluster.Servers.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=85,
)

_CLUSTER_SERVERS_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.cluster.Cluster.Servers.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='grakn.protocol.cluster.Cluster.Servers.Res.servers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='servers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=118,
)

_CLUSTER_SERVERS = _descriptor.Descriptor(
  name='Servers',
  full_name='grakn.protocol.cluster.Cluster.Servers',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_SERVERS_REQ, _CLUSTER_SERVERS_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=118,
)

_CLUSTER = _descriptor.Descriptor(
  name='Cluster',
  full_name='grakn.protocol.cluster.Cluster',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_CLUSTER_SERVERS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=118,
)

_CLUSTER_SERVERS_REQ.containing_type = _CLUSTER_SERVERS
_CLUSTER_SERVERS_RES.containing_type = _CLUSTER_SERVERS
_CLUSTER_SERVERS.containing_type = _CLUSTER
DESCRIPTOR.message_types_by_name['Cluster'] = _CLUSTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Cluster = _reflection.GeneratedProtocolMessageType('Cluster', (_message.Message,), dict(

  Servers = _reflection.GeneratedProtocolMessageType('Servers', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _CLUSTER_SERVERS_REQ,
      __module__ = 'protobuf.cluster.cluster_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _CLUSTER_SERVERS_RES,
      __module__ = 'protobuf.cluster.cluster_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers.Res)
      ))
    ,
    DESCRIPTOR = _CLUSTER_SERVERS,
    __module__ = 'protobuf.cluster.cluster_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster.Servers)
    ))
  ,
  DESCRIPTOR = _CLUSTER,
  __module__ = 'protobuf.cluster.cluster_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.cluster.Cluster)
  ))
_sym_db.RegisterMessage(Cluster)
_sym_db.RegisterMessage(Cluster.Servers)
_sym_db.RegisterMessage(Cluster.Servers.Req)
_sym_db.RegisterMessage(Cluster.Servers.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from grakn_protocol.protobuf import database_pb2 as protobuf_dot_database__pb2
from grakn_protocol.protobuf import session_pb2 as protobuf_dot_session__pb2
from grakn_protocol.protobuf import transaction_pb2 as protobuf_dot_transaction__pb2


class GraknStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.database_contains = channel.unary_unary(
        '/grakn.protocol.Grakn/database_contains',
        request_serializer=protobuf_dot_database__pb2.Database.Contains.Req.SerializeToString,
        response_deserializer=protobuf_dot_database__pb2.Database.Contains.Res.FromString,
        )
    self.database_create = channel.unary_unary(
        '/grakn.protocol.Grakn/database_create',
        request_serializer=protobuf_dot_database__pb2.Database.Create.Req.SerializeToString,
        response_deserializer=protobuf_dot_database__pb2.Database.Create.Res.FromString,
        )
    self.database_all = channel.unary_unary(
        '/grakn.protocol.Grakn/database_all',
        request_serializer=protobuf_dot_database__pb2.Database.All.Req.SerializeToString,
        response_deserializer=protobuf_dot_database__pb2.Database.All.Res.FromString,
        )
    self.database_delete = channel.unary_unary(
        '/grakn.protocol.Grakn/database_delete',
        request_serializer=protobuf_dot_database__pb2.Database.Delete.Req.SerializeToString,
        response_deserializer=protobuf_dot_database__pb2.Database.Delete.Res.FromString,
        )
    self.session_open = channel.unary_unary(
        '/grakn.protocol.Grakn/session_open',
        request_serializer=protobuf_dot_session__pb2.Session.Open.Req.SerializeToString,
        response_deserializer=protobuf_dot_session__pb2.Session.Open.Res.FromString,
        )
    self.session_close = channel.unary_unary(
        '/grakn.protocol.Grakn/session_close',
        request_serializer=protobuf_dot_session__pb2.Session.Close.Req.SerializeToString,
        response_deserializer=protobuf_dot_session__pb2.Session.Close.Res.FromString,
        )
    self.session_pulse = channel.unary_unary(
        '/grakn.protocol.Grakn/session_pulse',
        request_serializer=protobuf_dot_session__pb2.Session.Pulse.Req.SerializeToString,
        response_deserializer=protobuf_dot_session__pb2.Session.Pulse.Res.FromString,
        )
    self.transaction = channel.stream_stream(
        '/grakn.protocol.Grakn/transaction',
        request_serializer=protobuf_dot_transaction__pb2.Transaction.Req.SerializeToString,
        response_deserializer=protobuf_dot_transaction__pb2.Transaction.Res.FromString,
        )


class GraknServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def database_contains(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def database_create(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def database_all(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def database_delete(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def session_open(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def session_close(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def session_pulse(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def transaction(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_GraknServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'database_contains': grpc.unary_unary_rpc_method_handler(
          servicer.database_contains,
          request_deserializer=protobuf_dot_database__pb2.Database.Contains.Req.FromString,
          response_serializer=protobuf_dot_database__pb2.Database.Contains.Res.SerializeToString,
      ),
      'database_create': grpc.unary_unary_rpc_method_handler(
          servicer.database_create,
          request_deserializer=protobuf_dot_database__pb2.Database.Create.Req.FromString,
          response_serializer=protobuf_dot_database__pb2.Database.Create.Res.SerializeToString,
      ),
      'database_all': grpc.unary_unary_rpc_method_handler(
          servicer.database_all,
          request_deserializer=protobuf_dot_database__pb2.Database.All.Req.FromString,
          response_serializer=protobuf_dot_database__pb2.Database.All.Res.SerializeToString,
      ),
      'database_delete': grpc.unary_unary_rpc_method_handler(
          servicer.database_delete,
          request_deserializer=protobuf_dot_database__pb2.Database.Delete.Req.FromString,
          response_serializer=protobuf_dot_database__pb2.Database.Delete.Res.SerializeToString,
      ),
      'session_open': grpc.unary_unary_rpc_method_handler(
          servicer.session_open,
          request_deserializer=protobuf_dot_session__pb2.Session.Open.Req.FromString,
          response_serializer=protobuf_dot_session__pb2.Session.Open.Res.SerializeToString,
      ),
      'session_close': grpc.unary_unary_rpc_method_handler(
          servicer.session_close,
          request_deserializer=protobuf_dot_session__pb2.Session.Close.Req.FromString,
          response_serializer=protobuf_dot_session__pb2.Session.Close.Res.SerializeToString,
      ),
      'session_pulse': grpc.unary_unary_rpc_method_handler(
          servicer.session_pulse,
          request_deserializer=protobuf_dot_session__pb2.Session.Pulse.Req.FromString,
          response_serializer=protobuf_dot_session__pb2.Session.Pulse.Res.SerializeToString,
      ),
      'transaction': grpc.stream_stream_rpc_method_handler(
          servicer.transaction,
          request_deserializer=protobuf_dot_transaction__pb2.Transaction.Req.FromString,
          response_serializer=protobuf_dot_transaction__pb2.Transaction.Res.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'grakn.protocol.Grakn', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/transaction.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import concept_pb2 as protobuf_dot_concept__pb2
from grakn_protocol.protobuf import logic_pb2 as protobuf_dot_logic__pb2
from grakn_protocol.protobuf import options_pb2 as protobuf_dot_options__pb2
from grakn_protocol.protobuf import query_pb2 as protobuf_dot_query__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/transaction.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\020TransactionProto'),
  serialized_pb=_b('\n\x1aprotobuf/transaction.proto\x12\x0egrakn.protocol\x1a\x16protobuf/concept.proto\x1a\x14protobuf/logic.proto\x1a\x16protobuf/options.proto\x1a\x14protobuf/query.proto\"\xb7\x0e\n\x0bTransaction\x1a\xcc\x06\n\x03Req\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12I\n\x08metadata\x18\x02 \x03(\x0b\x32-.grakn.protocol.Transaction.Req.MetadataEntryR\x08metadata\x12%\n\x0elatency_millis\x18\x03 \x01(\x05R\rlatencyMillis\x12\x1c\n\x08\x63ontinue\x18\x04 \x01(\x08H\x00R\x08\x63ontinue\x12\x41\n\x08open_req\x18\x05 \x01(\x0b\x32$.grakn.protocol.Transaction.Open.ReqH\x00R\x07openReq\x12G\n\ncommit_req\x18\x06 \x01(\x0b\x32&.grakn.protocol.Transaction.Commit.ReqH\x00R\tcommitReq\x12M\n\x0crollback_req\x18\x07 \x01(\x0b\x32(.grakn.protocol.Transaction.Rollback.ReqH\x00R\x0brollbackReq\x12\x38\n\tquery_req\x18\x08 \x01(\x0b\x32\x19.grakn.protocol.Query.ReqH\x00R\x08queryReq\x12T\n\x13\x63oncept_manager_req\x18\t \x01(\x0b\x32\".grakn.protocol.ConceptManager.ReqH\x00R\x11\x63onceptManagerReq\x12\x38\n\tthing_req\x18\n \x01(\x0b\x32\x19.grakn.protocol.Thing.ReqH\x00R\x08thingReq\x12\x35\n\x08type_req\x18\x0b \x01(\x0b\x32\x18.grakn.protocol.Type.ReqH\x00R\x07typeReq\x12N\n\x11logic_manager_req\x18\x0c \x01(\x0b\x32 .grakn.protocol.LogicManager.ReqH\x00R\x0flogicManagerReq\x12\x35\n\x08rule_req\x18\r \x01(\x0b\x32\x18.grakn.protocol.Rule.ReqH\x00R\x07ruleReq\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x05\n\x03req\x1a\xb3\x05\n\x03Res\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x14\n\x04\x64one\x18\x02 \x01(\x08H\x00R\x04\x64one\x12\x1c\n\x08\x63ontinue\x18\x04 \x01(\x08H\x00R\x08\x63ontinue\x12\x41\n\x08open_res\x18\x05 \x01(\x0b\x32$.grakn.protocol.Transaction.Open.ResH\x00R\x07openRes\x12G\n\ncommit_res\x18\x06 \x01(\x0b\x32&.grakn.protocol.Transaction.Commit.ResH\x00R\tcommitRes\x12M\n\x0crollback_res\x18\x07 \x01(\x0b\x32(.grakn.protocol.Transaction.Rollback.ResH\x00R\x0brollbackRes\x12\x38\n\tquery_res\x18\x08 \x01(\x0b\x32\x19.grakn.protocol.Query.ResH\x00R\x08queryRes\x12T\n\x13\x63oncept_manager_res\x18\t \x01(\x0b\x32\".grakn.protocol.ConceptManager.ResH\x00R\x11\x63onceptManagerRes\x12\x38\n\tthing_res\x18\n \x01(\x0b\x32\x19.grakn.protocol.Thing.ResH\x00R\x08thingRes\x12\x35\n\x08type_res\x18\x0b \x01(\x0b\x32\x18.grakn.protocol.Type.ResH\x00R\x07typeRes\x12N\n\x11logic_manager_res\x18\x0c \x01(\x0b\x32 .grakn.protocol.LogicManager.ResH\x00R\x0flogicManagerRes\x12\x35\n\x08rule_res\x18\r \x01(\x0b\x32\x18.grakn.protocol.Rule.ResH\x00R\x07ruleResB\x05\n\x03res\x1a\xd3\x01\n\x04Open\x1a\x8d\x01\n\x03Req\x12\x1d\n\nsession_id\x18\x01 \x01(\x0cR\tsessionId\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32 .grakn.protocol.Transaction.TypeR\x04type\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32\x17.grakn.protocol.OptionsR\x07options\x1a;\n\x03Res\x12\x34\n\x16processing_time_millis\x18\x01 \x01(\x05R\x14processingTimeMillis\x1a\x16\n\x06\x43ommit\x1a\x05\n\x03Req\x1a\x05\n\x03Res\x1a\x18\n\x08Rollback\x1a\x05\n\x03Req\x1a\x05\n\x03Res\"\x1b\n\x04Type\x12\x08\n\x04READ\x10\x00\x12\t\n\x05WRITE\x10\x01\x42\"\n\x0egrakn.protocolB\x10TransactionProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_concept__pb2.DESCRIPTOR,protobuf_dot_logic__pb2.DESCRIPTOR,protobuf_dot_options__pb2.DESCRIPTOR,protobuf_dot_query__pb2.DESCRIPTOR,])



_TRANSACTION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='grakn.protocol.Transaction.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='READ', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WRITE', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1959,
  serialized_end=1986,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTION_TYPE)


_TRANSACTION_REQ_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='grakn.protocol.Transaction.Req.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='grakn.protocol.Transaction.Req.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grakn.protocol.Transaction.Req.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=992,
)

_TRANSACTION_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grakn.protocol.Transaction.Req.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='grakn.protocol.Transaction.Req.metadata', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='metadata', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_millis', full_name='grakn.protocol.Transaction.Req.latency_millis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='latencyMillis', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continue', full_name='grakn.protocol.Transaction.Req.continue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_req', full_name='grakn.protocol.Transaction.Req.open_req', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_req', full_name='grakn.protocol.Transaction.Req.commit_req', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_req', full_name='grakn.protocol.Transaction.Req.rollback_req', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rollbackReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_req', full_name='grakn.protocol.Transaction.Req.query_req', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_manager_req', full_name='grakn.protocol.Transaction.Req.concept_manager_req', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='conceptManagerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_req', full_name='grakn.protocol.Transaction.Req.thing_req', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_req', full_name='grakn.protocol.Transaction.Req.type_req', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logic_manager_req', full_name='grakn.protocol.Transaction.Req.logic_manager_req', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logicManagerReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_req', full_name='grakn.protocol.Transaction.Req.rule_req', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_REQ_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Transaction.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=155,
  serialized_end=999,
)

_TRANSACTION_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='grakn.protocol.Transaction.Res.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='done', full_name='grakn.protocol.Transaction.Res.done', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='done', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continue', full_name='grakn.protocol.Transaction.Res.continue', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='continue', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_res', full_name='grakn.protocol.Transaction.Res.open_res', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='openRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commit_res', full_name='grakn.protocol.Transaction.Res.commit_res', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rollback_res', full_name='grakn.protocol.Transaction.Res.rollback_res', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='rollbackRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_res', full_name='grakn.protocol.Transaction.Res.query_res', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_manager_res', full_name='grakn.protocol.Transaction.Res.concept_manager_res', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='conceptManagerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thing_res', full_name='grakn.protocol.Transaction.Res.thing_res', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='thingRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_res', full_name='grakn.protocol.Transaction.Res.type_res', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='typeRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logic_manager_res', full_name='grakn.protocol.Transaction.Res.logic_manager_res', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='logicManagerRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_res', full_name='grakn.protocol.Transaction.Res.rule_res', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ruleRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Transaction.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1002,
  serialized_end=1693,
)

_TRANSACTION_OPEN_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Open.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='grakn.protocol.Transaction.Open.Req.session_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Transaction.Open.Req.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='grakn.protocol.Transaction.Open.Req.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1846,
)

_TRANSACTION_OPEN_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Open.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processing_time_millis', full_name='grakn.protocol.Transaction.Open.Res.processing_time_millis', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='processingTimeMillis', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1848,
  serialized_end=1907,
)

_TRANSACTION_OPEN = _descriptor.Descriptor(
  name='Open',
  full_name='grakn.protocol.Transaction.Open',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_OPEN_REQ, _TRANSACTION_OPEN_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1696,
  serialized_end=1907,
)

_TRANSACTION_COMMIT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Commit.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=160,
)

_TRANSACTION_COMMIT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Commit.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1007,
)

_TRANSACTION_COMMIT = _descriptor.Descriptor(
  name='Commit',
  full_name='grakn.protocol.Transaction.Commit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_COMMIT_REQ, _TRANSACTION_COMMIT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=1931,
)

_TRANSACTION_ROLLBACK_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Transaction.Rollback.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=160,
)

_TRANSACTION_ROLLBACK_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Transaction.Rollback.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1002,
  serialized_end=1007,
)

_TRANSACTION_ROLLBACK = _descriptor.Descriptor(
  name='Rollback',
  full_name='grakn.protocol.Transaction.Rollback',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_ROLLBACK_REQ, _TRANSACTION_ROLLBACK_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1933,
  serialized_end=1957,
)

_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='grakn.protocol.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTION_REQ, _TRANSACTION_RES, _TRANSACTION_OPEN, _TRANSACTION_COMMIT, _TRANSACTION_ROLLBACK, ],
  enum_types=[
    _TRANSACTION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=1986,
)

_TRANSACTION_REQ_METADATAENTRY.containing_type = _TRANSACTION_REQ
_TRANSACTION_REQ.fields_by_name['metadata'].message_type = _TRANSACTION_REQ_METADATAENTRY
_TRANSACTION_REQ.fields_by_name['open_req'].message_type = _TRANSACTION_OPEN_REQ
_TRANSACTION_REQ.fields_by_name['commit_req'].message_type = _TRANSACTION_COMMIT_REQ
_TRANSACTION_REQ.fields_by_name['rollback_req'].message_type = _TRANSACTION_ROLLBACK_REQ
_TRANSACTION_REQ.fields_by_name['query_req'].message_type = protobuf_dot_query__pb2._QUERY_REQ
_TRANSACTION_REQ.fields_by_name['concept_manager_req'].message_type = protobuf_dot_concept__pb2._CONCEPTMANAGER_REQ
_TRANSACTION_REQ.fields_by_name['thing_req'].message_type = protobuf_dot_concept__pb2._THING_REQ
_TRANSACTION_REQ.fields_by_name['type_req'].message_type = protobuf_dot_concept__pb2._TYPE_REQ
_TRANSACTION_REQ.fields_by_name['logic_manager_req'].message_type = protobuf_dot_logic__pb2._LOGICMANAGER_REQ
_TRANSACTION_REQ.fields_by_name['rule_req'].message_type = protobuf_dot_logic__pb2._RULE_REQ
_TRANSACTION_REQ.containing_type = _TRANSACTION
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['continue'])
_TRANSACTION_REQ.fields_by_name['continue'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['open_req'])
_TRANSACTION_REQ.fields_by_name['open_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['commit_req'])
_TRANSACTION_REQ.fields_by_name['commit_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['rollback_req'])
_TRANSACTION_REQ.fields_by_name['rollback_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['query_req'])
_TRANSACTION_REQ.fields_by_name['query_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['concept_manager_req'])
_TRANSACTION_REQ.fields_by_name['concept_manager_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['thing_req'])
_TRANSACTION_REQ.fields_by_name['thing_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['type_req'])
_TRANSACTION_REQ.fields_by_name['type_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['logic_manager_req'])
_TRANSACTION_REQ.fields_by_name['logic_manager_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_REQ.oneofs_by_name['req'].fields.append(
  _TRANSACTION_REQ.fields_by_name['rule_req'])
_TRANSACTION_REQ.fields_by_name['rule_req'].containing_oneof = _TRANSACTION_REQ.oneofs_by_name['req']
_TRANSACTION_RES.fields_by_name['open_res'].message_type = _TRANSACTION_OPEN_RES
_TRANSACTION_RES.fields_by_name['commit_res'].message_type = _TRANSACTION_COMMIT_RES
_TRANSACTION_RES.fields_by_name['rollback_res'].message_type = _TRANSACTION_ROLLBACK_RES
_TRANSACTION_RES.fields_by_name['query_res'].message_type = protobuf_dot_query__pb2._QUERY_RES
_TRANSACTION_RES.fields_by_name['concept_manager_res'].message_type = protobuf_dot_concept__pb2._CONCEPTMANAGER_RES
_TRANSACTION_RES.fields_by_name['thing_res'].message_type = protobuf_dot_concept__pb2._THING_RES
_TRANSACTION_RES.fields_by_name['type_res'].message_type = protobuf_dot_concept__pb2._TYPE_RES
_TRANSACTION_RES.fields_by_name['logic_manager_res'].message_type = protobuf_dot_logic__pb2._LOGICMANAGER_RES
_TRANSACTION_RES.fields_by_name['rule_res'].message_type = protobuf_dot_logic__pb2._RULE_RES
_TRANSACTION_RES.containing_type = _TRANSACTION
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['done'])
_TRANSACTION_RES.fields_by_name['done'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['continue'])
_TRANSACTION_RES.fields_by_name['continue'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['open_res'])
_TRANSACTION_RES.fields_by_name['open_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['commit_res'])
_TRANSACTION_RES.fields_by_name['commit_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['rollback_res'])
_TRANSACTION_RES.fields_by_name['rollback_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['query_res'])
_TRANSACTION_RES.fields_by_name['query_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['concept_manager_res'])
_TRANSACTION_RES.fields_by_name['concept_manager_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['thing_res'])
_TRANSACTION_RES.fields_by_name['thing_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['type_res'])
_TRANSACTION_RES.fields_by_name['type_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['logic_manager_res'])
_TRANSACTION_RES.fields_by_name['logic_manager_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_RES.oneofs_by_name['res'].fields.append(
  _TRANSACTION_RES.fields_by_name['rule_res'])
_TRANSACTION_RES.fields_by_name['rule_res'].containing_oneof = _TRANSACTION_RES.oneofs_by_name['res']
_TRANSACTION_OPEN_REQ.fields_by_name['type'].enum_type = _TRANSACTION_TYPE
_TRANSACTION_OPEN_REQ.fields_by_name['options'].message_type = protobuf_dot_options__pb2._OPTIONS
_TRANSACTION_OPEN_REQ.containing_type = _TRANSACTION_OPEN
_TRANSACTION_OPEN_RES.containing_type = _TRANSACTION_OPEN
_TRANSACTION_OPEN.containing_type = _TRANSACTION
_TRANSACTION_COMMIT_REQ.containing_type = _TRANSACTION_COMMIT
_TRANSACTION_COMMIT_RES.containing_type = _TRANSACTION_COMMIT
_TRANSACTION_COMMIT.containing_type = _TRANSACTION
_TRANSACTION_ROLLBACK_REQ.containing_type = _TRANSACTION_ROLLBACK
_TRANSACTION_ROLLBACK_RES.containing_type = _TRANSACTION_ROLLBACK
_TRANSACTION_ROLLBACK.containing_type = _TRANSACTION
_TRANSACTION_TYPE.containing_type = _TRANSACTION
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(

    MetadataEntry = _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_REQ_METADATAENTRY,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Req.MetadataEntry)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_REQ,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _TRANSACTION_RES,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Res)
    ))
  ,

  Open = _reflection.GeneratedProtocolMessageType('Open', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_OPEN_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_OPEN_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_OPEN,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Open)
    ))
  ,

  Commit = _reflection.GeneratedProtocolMessageType('Commit', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_COMMIT_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_COMMIT_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_COMMIT,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Commit)
    ))
  ,

  Rollback = _reflection.GeneratedProtocolMessageType('Rollback', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_ROLLBACK_REQ,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _TRANSACTION_ROLLBACK_RES,
      __module__ = 'protobuf.transaction_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback.Res)
      ))
    ,
    DESCRIPTOR = _TRANSACTION_ROLLBACK,
    __module__ = 'protobuf.transaction_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction.Rollback)
    ))
  ,
  DESCRIPTOR = _TRANSACTION,
  __module__ = 'protobuf.transaction_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Transaction)
  ))
_sym_db.RegisterMessage(Transaction)
_sym_db.RegisterMessage(Transaction.Req)
_sym_db.RegisterMessage(Transaction.Req.MetadataEntry)
_sym_db.RegisterMessage(Transaction.Res)
_sym_db.RegisterMessage(Transaction.Open)
_sym_db.RegisterMessage(Transaction.Open.Req)
_sym_db.RegisterMessage(Transaction.Open.Res)
_sym_db.RegisterMessage(Transaction.Commit)
_sym_db.RegisterMessage(Transaction.Commit.Req)
_sym_db.RegisterMessage(Transaction.Commit.Res)
_sym_db.RegisterMessage(Transaction.Rollback)
_sym_db.RegisterMessage(Transaction.Rollback.Req)
_sym_db.RegisterMessage(Transaction.Rollback.Res)


DESCRIPTOR._options = None
_TRANSACTION_REQ_METADATAENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/cluster/grakn_cluster.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf.cluster import cluster_pb2 as protobuf_dot_cluster_dot_cluster__pb2
from grakn_protocol.protobuf.cluster import database_pb2 as protobuf_dot_cluster_dot_database__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/cluster/grakn_cluster.proto',
  package='grakn.protocol.cluster',
  syntax='proto3',
  serialized_options=_b('\n\026grakn.protocol.clusterB\021GraknClusterProto'),
  serialized_pb=_b('\n$protobuf/cluster/grakn_cluster.proto\x12\x16grakn.protocol.cluster\x1a\x1eprotobuf/cluster/cluster.proto\x1a\x1fprotobuf/cluster/database.proto2\xc3\x02\n\x0cGraknCluster\x12k\n\x0f\x63luster_servers\x12+.grakn.protocol.cluster.Cluster.Servers.Req\x1a+.grakn.protocol.cluster.Cluster.Servers.Res\x12\x62\n\x0c\x64\x61tabase_get\x12(.grakn.protocol.cluster.Database.Get.Req\x1a(.grakn.protocol.cluster.Database.Get.Res\x12\x62\n\x0c\x64\x61tabase_all\x12(.grakn.protocol.cluster.Database.All.Req\x1a(.grakn.protocol.cluster.Database.All.ResB+\n\x16grakn.protocol.clusterB\x11GraknClusterProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_cluster_dot_cluster__pb2.DESCRIPTOR,protobuf_dot_cluster_dot_database__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_GRAKNCLUSTER = _descriptor.ServiceDescriptor(
  name='GraknCluster',
  full_name='grakn.protocol.cluster.GraknCluster',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=130,
  serialized_end=453,
  methods=[
  _descriptor.MethodDescriptor(
    name='cluster_servers',
    full_name='grakn.protocol.cluster.GraknCluster.cluster_servers',
    index=0,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_cluster__pb2._CLUSTER_SERVERS_REQ,
    output_type=protobuf_dot_cluster_dot_cluster__pb2._CLUSTER_SERVERS_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_get',
    full_name='grakn.protocol.cluster.GraknCluster.database_get',
    index=1,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_GET_REQ,
    output_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_GET_RES,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='database_all',
    full_name='grakn.protocol.cluster.GraknCluster.database_all',
    index=2,
    containing_service=None,
    input_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_ALL_REQ,
    output_type=protobuf_dot_cluster_dot_database__pb2._DATABASE_ALL_RES,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_GRAKNCLUSTER)

DESCRIPTOR.services_by_name['GraknCluster'] = _GRAKNCLUSTER

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/session.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import options_pb2 as protobuf_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/session.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\014SessionProto'),
  serialized_pb=_b('\n\x16protobuf/session.proto\x12\x0egrakn.protocol\x1a\x16protobuf/options.proto\"\xe1\x02\n\x07Session\x1a\xb5\x01\n\x04Open\x1a\x86\x01\n\x03Req\x12\x1a\n\x08\x64\x61tabase\x18\x01 \x01(\tR\x08\x64\x61tabase\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\x1c.grakn.protocol.Session.TypeR\x04type\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32\x17.grakn.protocol.OptionsR\x07options\x1a$\n\x03Res\x12\x1d\n\nsession_id\x18\x01 \x01(\x0cR\tsessionId\x1a\x34\n\x05\x43lose\x1a$\n\x03Req\x12\x1d\n\nsession_id\x18\x01 \x01(\x0cR\tsessionId\x1a\x05\n\x03Res\x1aJ\n\x05Pulse\x1a$\n\x03Req\x12\x1d\n\nsession_id\x18\x01 \x01(\x0cR\tsessionId\x1a\x1b\n\x03Res\x12\x14\n\x05\x61live\x18\x01 \x01(\x08R\x05\x61live\"\x1c\n\x04Type\x12\x08\n\x04\x44\x41TA\x10\x00\x12\n\n\x06SCHEMA\x10\x01\x42\x1e\n\x0egrakn.protocolB\x0cSessionProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_options__pb2.DESCRIPTOR,])



_SESSION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='grakn.protocol.Session.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEMA', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=392,
  serialized_end=420,
)
_sym_db.RegisterEnumDescriptor(_SESSION_TYPE)


_SESSION_OPEN_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Session.Open.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='database', full_name='grakn.protocol.Session.Open.Req.database', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='database', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='grakn.protocol.Session.Open.Req.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='options', full_name='grakn.protocol.Session.Open.Req.options', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=222,
)

_SESSION_OPEN_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Session.Open.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='grakn.protocol.Session.Open.Res.session_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=260,
)

_SESSION_OPEN = _descriptor.Descriptor(
  name='Open',
  full_name='grakn.protocol.Session.Open',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SESSION_OPEN_REQ, _SESSION_OPEN_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=260,
)

_SESSION_CLOSE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Session.Close.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='grakn.protocol.Session.Close.Req.session_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=307,
)

_SESSION_CLOSE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Session.Close.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=224,
  serialized_end=229,
)

_SESSION_CLOSE = _descriptor.Descriptor(
  name='Close',
  full_name='grakn.protocol.Session.Close',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SESSION_CLOSE_REQ, _SESSION_CLOSE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=314,
)

_SESSION_PULSE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Session.Pulse.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='grakn.protocol.Session.Pulse.Req.session_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sessionId', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=307,
)

_SESSION_PULSE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Session.Pulse.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alive', full_name='grakn.protocol.Session.Pulse.Res.alive', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='alive', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=390,
)

_SESSION_PULSE = _descriptor.Descriptor(
  name='Pulse',
  full_name='grakn.protocol.Session.Pulse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SESSION_PULSE_REQ, _SESSION_PULSE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=316,
  serialized_end=390,
)

_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='grakn.protocol.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_SESSION_OPEN, _SESSION_CLOSE, _SESSION_PULSE, ],
  enum_types=[
    _SESSION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=420,
)

_SESSION_OPEN_REQ.fields_by_name['type'].enum_type = _SESSION_TYPE
_SESSION_OPEN_REQ.fields_by_name['options'].message_type = protobuf_dot_options__pb2._OPTIONS
_SESSION_OPEN_REQ.containing_type = _SESSION_OPEN
_SESSION_OPEN_RES.containing_type = _SESSION_OPEN
_SESSION_OPEN.containing_type = _SESSION
_SESSION_CLOSE_REQ.containing_type = _SESSION_CLOSE
_SESSION_CLOSE_RES.containing_type = _SESSION_CLOSE
_SESSION_CLOSE.containing_type = _SESSION
_SESSION_PULSE_REQ.containing_type = _SESSION_PULSE
_SESSION_PULSE_RES.containing_type = _SESSION_PULSE
_SESSION_PULSE.containing_type = _SESSION
_SESSION_TYPE.containing_type = _SESSION
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(

  Open = _reflection.GeneratedProtocolMessageType('Open', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_OPEN_REQ,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Open.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_OPEN_RES,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Open.Res)
      ))
    ,
    DESCRIPTOR = _SESSION_OPEN,
    __module__ = 'protobuf.session_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Open)
    ))
  ,

  Close = _reflection.GeneratedProtocolMessageType('Close', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_CLOSE_REQ,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Close.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_CLOSE_RES,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Close.Res)
      ))
    ,
    DESCRIPTOR = _SESSION_CLOSE,
    __module__ = 'protobuf.session_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Close)
    ))
  ,

  Pulse = _reflection.GeneratedProtocolMessageType('Pulse', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_PULSE_REQ,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Pulse.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _SESSION_PULSE_RES,
      __module__ = 'protobuf.session_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Pulse.Res)
      ))
    ,
    DESCRIPTOR = _SESSION_PULSE,
    __module__ = 'protobuf.session_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Session.Pulse)
    ))
  ,
  DESCRIPTOR = _SESSION,
  __module__ = 'protobuf.session_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Session)
  ))
_sym_db.RegisterMessage(Session)
_sym_db.RegisterMessage(Session.Open)
_sym_db.RegisterMessage(Session.Open.Req)
_sym_db.RegisterMessage(Session.Open.Res)
_sym_db.RegisterMessage(Session.Close)
_sym_db.RegisterMessage(Session.Close.Req)
_sym_db.RegisterMessage(Session.Close.Res)
_sym_db.RegisterMessage(Session.Pulse)
_sym_db.RegisterMessage(Session.Pulse.Req)
_sym_db.RegisterMessage(Session.Pulse.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobuf/query.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from grakn_protocol.protobuf import answer_pb2 as protobuf_dot_answer__pb2
from grakn_protocol.protobuf import options_pb2 as protobuf_dot_options__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobuf/query.proto',
  package='grakn.protocol',
  syntax='proto3',
  serialized_options=_b('\n\016grakn.protocolB\nQueryProto'),
  serialized_pb=_b('\n\x14protobuf/query.proto\x12\x0egrakn.protocol\x1a\x15protobuf/answer.proto\x1a\x16protobuf/options.proto\"\xb0\x11\n\x05Query\x1a\xec\x05\n\x03Req\x12\x31\n\x07options\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.OptionsR\x07options\x12\x41\n\ndefine_req\x18\x64 \x01(\x0b\x32 .grakn.protocol.Query.Define.ReqH\x00R\tdefineReq\x12G\n\x0cundefine_req\x18\x65 \x01(\x0b\x32\".grakn.protocol.Query.Undefine.ReqH\x00R\x0bundefineReq\x12>\n\tmatch_req\x18\x66 \x01(\x0b\x32\x1f.grakn.protocol.Query.Match.ReqH\x00R\x08matchReq\x12Z\n\x13match_aggregate_req\x18g \x01(\x0b\x32(.grakn.protocol.Query.MatchAggregate.ReqH\x00R\x11matchAggregateReq\x12N\n\x0fmatch_group_req\x18h \x01(\x0b\x32$.grakn.protocol.Query.MatchGroup.ReqH\x00R\rmatchGroupReq\x12j\n\x19match_group_aggregate_req\x18i \x01(\x0b\x32-.grakn.protocol.Query.MatchGroupAggregate.ReqH\x00R\x16matchGroupAggregateReq\x12\x41\n\ninsert_req\x18j \x01(\x0b\x32 .grakn.protocol.Query.Insert.ReqH\x00R\tinsertReq\x12\x41\n\ndelete_req\x18k \x01(\x0b\x32 .grakn.protocol.Query.Delete.ReqH\x00R\tdeleteReq\x12\x41\n\nupdate_req\x18l \x01(\x0b\x32 .grakn.protocol.Query.Update.ReqH\x00R\tupdateReqB\x05\n\x03req\x1a\xb9\x05\n\x03Res\x12\x41\n\ndefine_res\x18\x64 \x01(\x0b\x32 .grakn.protocol.Query.Define.ResH\x00R\tdefineRes\x12G\n\x0cundefine_res\x18\x65 \x01(\x0b\x32\".grakn.protocol.Query.Undefine.ResH\x00R\x0bundefineRes\x12>\n\tmatch_res\x18\x66 \x01(\x0b\x32\x1f.grakn.protocol.Query.Match.ResH\x00R\x08matchRes\x12Z\n\x13match_aggregate_res\x18g \x01(\x0b\x32(.grakn.protocol.Query.MatchAggregate.ResH\x00R\x11matchAggregateRes\x12N\n\x0fmatch_group_res\x18h \x01(\x0b\x32$.grakn.protocol.Query.MatchGroup.ResH\x00R\rmatchGroupRes\x12j\n\x19match_group_aggregate_res\x18i \x01(\x0b\x32-.grakn.protocol.Query.MatchGroupAggregate.ResH\x00R\x16matchGroupAggregateRes\x12\x41\n\ninsert_res\x18j \x01(\x0b\x32 .grakn.protocol.Query.Insert.ResH\x00R\tinsertRes\x12\x41\n\ndelete_res\x18k \x01(\x0b\x32 .grakn.protocol.Query.Delete.ResH\x00R\tdeleteRes\x12\x41\n\nupdate_res\x18l \x01(\x0b\x32 .grakn.protocol.Query.Update.ResH\x00R\tupdateResB\x05\n\x03res\x1a\x61\n\x05Match\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a\x65\n\x0eMatchAggregate\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x36\n\x03Res\x12/\n\x06\x61nswer\x18\x01 \x01(\x0b\x32\x17.grakn.protocol.NumericR\x06\x61nswer\x1ak\n\nMatchGroup\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a@\n\x03Res\x12\x39\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1f.grakn.protocol.ConceptMapGroupR\x07\x61nswers\x1aq\n\x13MatchGroupAggregate\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a=\n\x03Res\x12\x36\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1c.grakn.protocol.NumericGroupR\x07\x61nswers\x1a\x62\n\x06Insert\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a,\n\x06\x44\x65lete\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03Res\x1a\x62\n\x06Update\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a;\n\x03Res\x12\x34\n\x07\x61nswers\x18\x01 \x03(\x0b\x32\x1a.grakn.protocol.ConceptMapR\x07\x61nswers\x1a,\n\x06\x44\x65\x66ine\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03Res\x1a.\n\x08Undefine\x1a\x1b\n\x03Req\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x1a\x05\n\x03ResB\x1c\n\x0egrakn.protocolB\nQueryProtob\x06proto3')
  ,
  dependencies=[protobuf_dot_answer__pb2.DESCRIPTOR,protobuf_dot_options__pb2.DESCRIPTOR,])




_QUERY_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='options', full_name='grakn.protocol.Query.Req.options', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='options', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='define_req', full_name='grakn.protocol.Query.Req.define_req', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defineReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undefine_req', full_name='grakn.protocol.Query.Req.undefine_req', index=2,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='undefineReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_req', full_name='grakn.protocol.Query.Req.match_req', index=3,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_aggregate_req', full_name='grakn.protocol.Query.Req.match_aggregate_req', index=4,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchAggregateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_req', full_name='grakn.protocol.Query.Req.match_group_req', index=5,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_aggregate_req', full_name='grakn.protocol.Query.Req.match_group_aggregate_req', index=6,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupAggregateReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_req', full_name='grakn.protocol.Query.Req.insert_req', index=7,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='insertReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_req', full_name='grakn.protocol.Query.Req.delete_req', index=8,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deleteReq', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_req', full_name='grakn.protocol.Query.Req.update_req', index=9,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateReq', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='req', full_name='grakn.protocol.Query.Req.req',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=98,
  serialized_end=846,
)

_QUERY_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='define_res', full_name='grakn.protocol.Query.Res.define_res', index=0,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='defineRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='undefine_res', full_name='grakn.protocol.Query.Res.undefine_res', index=1,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='undefineRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_res', full_name='grakn.protocol.Query.Res.match_res', index=2,
      number=102, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_aggregate_res', full_name='grakn.protocol.Query.Res.match_aggregate_res', index=3,
      number=103, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchAggregateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_res', full_name='grakn.protocol.Query.Res.match_group_res', index=4,
      number=104, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='match_group_aggregate_res', full_name='grakn.protocol.Query.Res.match_group_aggregate_res', index=5,
      number=105, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='matchGroupAggregateRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='insert_res', full_name='grakn.protocol.Query.Res.insert_res', index=6,
      number=106, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='insertRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delete_res', full_name='grakn.protocol.Query.Res.delete_res', index=7,
      number=107, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='deleteRes', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_res', full_name='grakn.protocol.Query.Res.update_res', index=8,
      number=108, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='updateRes', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='res', full_name='grakn.protocol.Query.Res.res',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=849,
  serialized_end=1546,
)

_QUERY_MATCH_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Match.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Match.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCH_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Match.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Match.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_MATCH = _descriptor.Descriptor(
  name='Match',
  full_name='grakn.protocol.Query.Match',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCH_REQ, _QUERY_MATCH_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1548,
  serialized_end=1645,
)

_QUERY_MATCHAGGREGATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchAggregate.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchAggregate.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHAGGREGATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchAggregate.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answer', full_name='grakn.protocol.Query.MatchAggregate.Res.answer', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answer', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1694,
  serialized_end=1748,
)

_QUERY_MATCHAGGREGATE = _descriptor.Descriptor(
  name='MatchAggregate',
  full_name='grakn.protocol.Query.MatchAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHAGGREGATE_REQ, _QUERY_MATCHAGGREGATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1647,
  serialized_end=1748,
)

_QUERY_MATCHGROUP_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchGroup.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchGroup.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHGROUP_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchGroup.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.MatchGroup.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1857,
)

_QUERY_MATCHGROUP = _descriptor.Descriptor(
  name='MatchGroup',
  full_name='grakn.protocol.Query.MatchGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHGROUP_REQ, _QUERY_MATCHGROUP_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1857,
)

_QUERY_MATCHGROUPAGGREGATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.MatchGroupAggregate.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.MatchGroupAggregate.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_MATCHGROUPAGGREGATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.MatchGroupAggregate.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.MatchGroupAggregate.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1911,
  serialized_end=1972,
)

_QUERY_MATCHGROUPAGGREGATE = _descriptor.Descriptor(
  name='MatchGroupAggregate',
  full_name='grakn.protocol.Query.MatchGroupAggregate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_MATCHGROUPAGGREGATE_REQ, _QUERY_MATCHGROUPAGGREGATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1859,
  serialized_end=1972,
)

_QUERY_INSERT_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Insert.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Insert.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_INSERT_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Insert.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Insert.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_INSERT = _descriptor.Descriptor(
  name='Insert',
  full_name='grakn.protocol.Query.Insert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_INSERT_REQ, _QUERY_INSERT_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1974,
  serialized_end=2072,
)

_QUERY_DELETE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Delete.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Delete.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_DELETE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Delete.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_DELETE = _descriptor.Descriptor(
  name='Delete',
  full_name='grakn.protocol.Query.Delete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_DELETE_REQ, _QUERY_DELETE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2074,
  serialized_end=2118,
)

_QUERY_UPDATE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Update.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Update.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_UPDATE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Update.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='answers', full_name='grakn.protocol.Query.Update.Res.answers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='answers', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1586,
  serialized_end=1645,
)

_QUERY_UPDATE = _descriptor.Descriptor(
  name='Update',
  full_name='grakn.protocol.Query.Update',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_UPDATE_REQ, _QUERY_UPDATE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2120,
  serialized_end=2218,
)

_QUERY_DEFINE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Define.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Define.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_DEFINE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Define.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_DEFINE = _descriptor.Descriptor(
  name='Define',
  full_name='grakn.protocol.Query.Define',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_DEFINE_REQ, _QUERY_DEFINE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2264,
)

_QUERY_UNDEFINE_REQ = _descriptor.Descriptor(
  name='Req',
  full_name='grakn.protocol.Query.Undefine.Req',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='grakn.protocol.Query.Undefine.Req.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1584,
)

_QUERY_UNDEFINE_RES = _descriptor.Descriptor(
  name='Res',
  full_name='grakn.protocol.Query.Undefine.Res',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=849,
  serialized_end=854,
)

_QUERY_UNDEFINE = _descriptor.Descriptor(
  name='Undefine',
  full_name='grakn.protocol.Query.Undefine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_UNDEFINE_REQ, _QUERY_UNDEFINE_RES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2266,
  serialized_end=2312,
)

_QUERY = _descriptor.Descriptor(
  name='Query',
  full_name='grakn.protocol.Query',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[_QUERY_REQ, _QUERY_RES, _QUERY_MATCH, _QUERY_MATCHAGGREGATE, _QUERY_MATCHGROUP, _QUERY_MATCHGROUPAGGREGATE, _QUERY_INSERT, _QUERY_DELETE, _QUERY_UPDATE, _QUERY_DEFINE, _QUERY_UNDEFINE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=88,
  serialized_end=2312,
)

_QUERY_REQ.fields_by_name['options'].message_type = protobuf_dot_options__pb2._OPTIONS
_QUERY_REQ.fields_by_name['define_req'].message_type = _QUERY_DEFINE_REQ
_QUERY_REQ.fields_by_name['undefine_req'].message_type = _QUERY_UNDEFINE_REQ
_QUERY_REQ.fields_by_name['match_req'].message_type = _QUERY_MATCH_REQ
_QUERY_REQ.fields_by_name['match_aggregate_req'].message_type = _QUERY_MATCHAGGREGATE_REQ
_QUERY_REQ.fields_by_name['match_group_req'].message_type = _QUERY_MATCHGROUP_REQ
_QUERY_REQ.fields_by_name['match_group_aggregate_req'].message_type = _QUERY_MATCHGROUPAGGREGATE_REQ
_QUERY_REQ.fields_by_name['insert_req'].message_type = _QUERY_INSERT_REQ
_QUERY_REQ.fields_by_name['delete_req'].message_type = _QUERY_DELETE_REQ
_QUERY_REQ.fields_by_name['update_req'].message_type = _QUERY_UPDATE_REQ
_QUERY_REQ.containing_type = _QUERY
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['define_req'])
_QUERY_REQ.fields_by_name['define_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['undefine_req'])
_QUERY_REQ.fields_by_name['undefine_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_req'])
_QUERY_REQ.fields_by_name['match_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_aggregate_req'])
_QUERY_REQ.fields_by_name['match_aggregate_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_group_req'])
_QUERY_REQ.fields_by_name['match_group_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['match_group_aggregate_req'])
_QUERY_REQ.fields_by_name['match_group_aggregate_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['insert_req'])
_QUERY_REQ.fields_by_name['insert_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['delete_req'])
_QUERY_REQ.fields_by_name['delete_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_REQ.oneofs_by_name['req'].fields.append(
  _QUERY_REQ.fields_by_name['update_req'])
_QUERY_REQ.fields_by_name['update_req'].containing_oneof = _QUERY_REQ.oneofs_by_name['req']
_QUERY_RES.fields_by_name['define_res'].message_type = _QUERY_DEFINE_RES
_QUERY_RES.fields_by_name['undefine_res'].message_type = _QUERY_UNDEFINE_RES
_QUERY_RES.fields_by_name['match_res'].message_type = _QUERY_MATCH_RES
_QUERY_RES.fields_by_name['match_aggregate_res'].message_type = _QUERY_MATCHAGGREGATE_RES
_QUERY_RES.fields_by_name['match_group_res'].message_type = _QUERY_MATCHGROUP_RES
_QUERY_RES.fields_by_name['match_group_aggregate_res'].message_type = _QUERY_MATCHGROUPAGGREGATE_RES
_QUERY_RES.fields_by_name['insert_res'].message_type = _QUERY_INSERT_RES
_QUERY_RES.fields_by_name['delete_res'].message_type = _QUERY_DELETE_RES
_QUERY_RES.fields_by_name['update_res'].message_type = _QUERY_UPDATE_RES
_QUERY_RES.containing_type = _QUERY
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['define_res'])
_QUERY_RES.fields_by_name['define_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['undefine_res'])
_QUERY_RES.fields_by_name['undefine_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_res'])
_QUERY_RES.fields_by_name['match_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_aggregate_res'])
_QUERY_RES.fields_by_name['match_aggregate_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_group_res'])
_QUERY_RES.fields_by_name['match_group_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['match_group_aggregate_res'])
_QUERY_RES.fields_by_name['match_group_aggregate_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['insert_res'])
_QUERY_RES.fields_by_name['insert_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['delete_res'])
_QUERY_RES.fields_by_name['delete_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_RES.oneofs_by_name['res'].fields.append(
  _QUERY_RES.fields_by_name['update_res'])
_QUERY_RES.fields_by_name['update_res'].containing_oneof = _QUERY_RES.oneofs_by_name['res']
_QUERY_MATCH_REQ.containing_type = _QUERY_MATCH
_QUERY_MATCH_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_MATCH_RES.containing_type = _QUERY_MATCH
_QUERY_MATCH.containing_type = _QUERY
_QUERY_MATCHAGGREGATE_REQ.containing_type = _QUERY_MATCHAGGREGATE
_QUERY_MATCHAGGREGATE_RES.fields_by_name['answer'].message_type = protobuf_dot_answer__pb2._NUMERIC
_QUERY_MATCHAGGREGATE_RES.containing_type = _QUERY_MATCHAGGREGATE
_QUERY_MATCHAGGREGATE.containing_type = _QUERY
_QUERY_MATCHGROUP_REQ.containing_type = _QUERY_MATCHGROUP
_QUERY_MATCHGROUP_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAPGROUP
_QUERY_MATCHGROUP_RES.containing_type = _QUERY_MATCHGROUP
_QUERY_MATCHGROUP.containing_type = _QUERY
_QUERY_MATCHGROUPAGGREGATE_REQ.containing_type = _QUERY_MATCHGROUPAGGREGATE
_QUERY_MATCHGROUPAGGREGATE_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._NUMERICGROUP
_QUERY_MATCHGROUPAGGREGATE_RES.containing_type = _QUERY_MATCHGROUPAGGREGATE
_QUERY_MATCHGROUPAGGREGATE.containing_type = _QUERY
_QUERY_INSERT_REQ.containing_type = _QUERY_INSERT
_QUERY_INSERT_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_INSERT_RES.containing_type = _QUERY_INSERT
_QUERY_INSERT.containing_type = _QUERY
_QUERY_DELETE_REQ.containing_type = _QUERY_DELETE
_QUERY_DELETE_RES.containing_type = _QUERY_DELETE
_QUERY_DELETE.containing_type = _QUERY
_QUERY_UPDATE_REQ.containing_type = _QUERY_UPDATE
_QUERY_UPDATE_RES.fields_by_name['answers'].message_type = protobuf_dot_answer__pb2._CONCEPTMAP
_QUERY_UPDATE_RES.containing_type = _QUERY_UPDATE
_QUERY_UPDATE.containing_type = _QUERY
_QUERY_DEFINE_REQ.containing_type = _QUERY_DEFINE
_QUERY_DEFINE_RES.containing_type = _QUERY_DEFINE
_QUERY_DEFINE.containing_type = _QUERY
_QUERY_UNDEFINE_REQ.containing_type = _QUERY_UNDEFINE
_QUERY_UNDEFINE_RES.containing_type = _QUERY_UNDEFINE
_QUERY_UNDEFINE.containing_type = _QUERY
DESCRIPTOR.message_types_by_name['Query'] = _QUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Query = _reflection.GeneratedProtocolMessageType('Query', (_message.Message,), dict(

  Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
    DESCRIPTOR = _QUERY_REQ,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Req)
    ))
  ,

  Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
    DESCRIPTOR = _QUERY_RES,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Res)
    ))
  ,

  Match = _reflection.GeneratedProtocolMessageType('Match', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCH_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCH_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCH,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Match)
    ))
  ,

  MatchAggregate = _reflection.GeneratedProtocolMessageType('MatchAggregate', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHAGGREGATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHAGGREGATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHAGGREGATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchAggregate)
    ))
  ,

  MatchGroup = _reflection.GeneratedProtocolMessageType('MatchGroup', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUP_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUP_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHGROUP,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroup)
    ))
  ,

  MatchGroupAggregate = _reflection.GeneratedProtocolMessageType('MatchGroupAggregate', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_MATCHGROUPAGGREGATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.MatchGroupAggregate)
    ))
  ,

  Insert = _reflection.GeneratedProtocolMessageType('Insert', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_INSERT_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_INSERT_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_INSERT,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Insert)
    ))
  ,

  Delete = _reflection.GeneratedProtocolMessageType('Delete', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DELETE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DELETE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_DELETE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Delete)
    ))
  ,

  Update = _reflection.GeneratedProtocolMessageType('Update', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UPDATE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UPDATE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_UPDATE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Update)
    ))
  ,

  Define = _reflection.GeneratedProtocolMessageType('Define', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DEFINE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_DEFINE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_DEFINE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Define)
    ))
  ,

  Undefine = _reflection.GeneratedProtocolMessageType('Undefine', (_message.Message,), dict(

    Req = _reflection.GeneratedProtocolMessageType('Req', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UNDEFINE_REQ,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine.Req)
      ))
    ,

    Res = _reflection.GeneratedProtocolMessageType('Res', (_message.Message,), dict(
      DESCRIPTOR = _QUERY_UNDEFINE_RES,
      __module__ = 'protobuf.query_pb2'
      # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine.Res)
      ))
    ,
    DESCRIPTOR = _QUERY_UNDEFINE,
    __module__ = 'protobuf.query_pb2'
    # @@protoc_insertion_point(class_scope:grakn.protocol.Query.Undefine)
    ))
  ,
  DESCRIPTOR = _QUERY,
  __module__ = 'protobuf.query_pb2'
  # @@protoc_insertion_point(class_scope:grakn.protocol.Query)
  ))
_sym_db.RegisterMessage(Query)
_sym_db.RegisterMessage(Query.Req)
_sym_db.RegisterMessage(Query.Res)
_sym_db.RegisterMessage(Query.Match)
_sym_db.RegisterMessage(Query.Match.Req)
_sym_db.RegisterMessage(Query.Match.Res)
_sym_db.RegisterMessage(Query.MatchAggregate)
_sym_db.RegisterMessage(Query.MatchAggregate.Req)
_sym_db.RegisterMessage(Query.MatchAggregate.Res)
_sym_db.RegisterMessage(Query.MatchGroup)
_sym_db.RegisterMessage(Query.MatchGroup.Req)
_sym_db.RegisterMessage(Query.MatchGroup.Res)
_sym_db.RegisterMessage(Query.MatchGroupAggregate)
_sym_db.RegisterMessage(Query.MatchGroupAggregate.Req)
_sym_db.RegisterMessage(Query.MatchGroupAggregate.Res)
_sym_db.RegisterMessage(Query.Insert)
_sym_db.RegisterMessage(Query.Insert.Req)
_sym_db.RegisterMessage(Query.Insert.Res)
_sym_db.RegisterMessage(Query.Delete)
_sym_db.RegisterMessage(Query.Delete.Req)
_sym_db.RegisterMessage(Query.Delete.Res)
_sym_db.RegisterMessage(Query.Update)
_sym_db.RegisterMessage(Query.Update.Req)
_sym_db.RegisterMessage(Query.Update.Res)
_sym_db.RegisterMessage(Query.Define)
_sym_db.RegisterMessage(Query.Define.Req)
_sym_db.RegisterMessage(Query.Define.Res)
_sym_db.RegisterMessage(Query.Undefine)
_sym_db.RegisterMessage(Query.Undefine.Req)
_sym_db.RegisterMessage(Query.Undefine.Res)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
